searchNodes=[{"doc":"Documentation for ExPomodoro .","ref":"ExPomodoro.html","title":"ExPomodoro","type":"module"},{"doc":"Returns the Elixir.ExPomodoro child spec. It is intended for appliations to add an Elixir.ExPomodoro child spec to their application trees to have an Elixir.ExPomodoro.Supervisor started before interacting with the rest of the Elixir.ExPomodoro commands.","ref":"ExPomodoro.html#child_spec/1","title":"ExPomodoro.child_spec/1","type":"function"},{"doc":"Generally this function is used to check whether a Pomodoro exists or not. Given an id , if a Pomodoro exists, a Elixir.ExPomodoro.Pomodoro struct is returned, othwerise returns an error tuple. Examples: # Return a pomodoro. iex&gt; ExPomodoro . get ( &quot;some id&quot; ) { :ok , % ExPomodoro.Pomodoro { id : &quot;some id&quot; } } # Get a pomodoro that does not exist. iex&gt; ExPomodoro . get ( &quot;some other id&quot; ) { :error , :not_found }","ref":"ExPomodoro.html#get/1","title":"ExPomodoro.get/1","type":"function"},{"doc":"The Pomodoro timer can be paused using this function. While this function will cause a pomodoro to pause, it can still finish by timeout, defined in the Elixir.ExPomodoro.PomodoroServer implementation. Given an id , returns a Elixir.ExPomodoro.Pomodoro struct or an error tuple if the pomodoro does not exist. Examples: # Pause a pomodoro and returns the remaining timeleft to complete the # current activity. iex&gt; ExPomodoro . pause ( &quot;some id&quot; ) { :ok , % Pomodoro { id : &quot;some id&quot; , activity : :idle , current_duration : timeleft } } # Pause a pomodoro that does not exist. iex&gt; ExPomodoro . pause ( &quot;some id&quot; ) { :error , :not_found }","ref":"ExPomodoro.html#pause/1","title":"ExPomodoro.pause/1","type":"function"},{"doc":"This is the main function to start a pomodoro. Given an id and an optional keyword of options returns a successful response if a Pomodoro has been started or resumed. Every successful responses returns the current Elixir.ExPomodoro.Pomodoro struct. Options exercise_duration : The duration in milliseconds of the exercise duration, non_negative_integer() . break_duration : The duration in milliseconds of the break duration, non_negative_integer() . rounds : The number of rounds until a long break, non_negative_integer() . Examples: # Start a pomodoro with default options. iex&gt; ExPomodoro . start ( &quot;some id&quot; ) { :ok , % ExPomodoro.Pomodoro { id : &quot;some id&quot; , activity : :exercise , exercise_duration : 1_500_000 , break_duration : 300_000 , rounds : 4 } } # Start a pomodoro with some options. iex&gt; ExPomodoro . start ( &quot;some id&quot; , [ ...&gt; exercise_duration : 150_000 , ...&gt; break_duration : 25_000 , ...&gt; rounds : 8 ...&gt; ] ) { :ok , % ExPomodoro.Pomodoro { id : &quot;some id&quot; , activity : :exercise , exercise_duration : 150_000 , break_duration : 25_000 , rounds : 8 } } # Start a pomodoro that is already running. iex&gt; ExPomodoro . start ( &quot;some_id&quot; ) { :ok , { :already_started , % Pomodoro { id : &quot;some id&quot; } } } # Start a pomodoro that already finished. iex&gt; ExPomodoro . start ( &quot;some_id&quot; ) { :ok , { :already_finished , % Pomodoro { id : &quot;some id&quot; } } } # Start a pomodoro that was paused or finished a break. iex&gt; ExPomodoro . start ( &quot;some_id&quot; ) { :ok , { :resumed , % Pomodoro { id : &quot;some id&quot; } } }","ref":"ExPomodoro.html#start/2","title":"ExPomodoro.start/2","type":"function"},{"doc":"","ref":"ExPomodoro.html#t:already_finished_response/0","title":"ExPomodoro.already_finished_response/0","type":"type"},{"doc":"","ref":"ExPomodoro.html#t:already_started_response/0","title":"ExPomodoro.already_started_response/0","type":"type"},{"doc":"","ref":"ExPomodoro.html#t:not_found_response/0","title":"ExPomodoro.not_found_response/0","type":"type"},{"doc":"","ref":"ExPomodoro.html#t:resumed_response/0","title":"ExPomodoro.resumed_response/0","type":"type"},{"doc":"","ref":"ExPomodoro.html#t:started_response/0","title":"ExPomodoro.started_response/0","type":"type"},{"doc":"","ref":"ExPomodoro.html#t:success_response/0","title":"ExPomodoro.success_response/0","type":"type"},{"doc":"This module is repsonsible for defining the domain model for the Pomodoro technique.","ref":"ExPomodoro.Pomodoro.html","title":"ExPomodoro.Pomodoro","type":"module"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct, returns a new struct in a break activity.","ref":"ExPomodoro.Pomodoro.html#break/1","title":"ExPomodoro.Pomodoro.break/1","type":"function"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct, completes the current round by assigning a new activity.","ref":"ExPomodoro.Pomodoro.html#complete_round/1","title":"ExPomodoro.Pomodoro.complete_round/1","type":"function"},{"doc":"The default duration of breaks.","ref":"ExPomodoro.Pomodoro.html#default_break_duration/0","title":"ExPomodoro.Pomodoro.default_break_duration/0","type":"function"},{"doc":"The default duration of the exercise.","ref":"ExPomodoro.Pomodoro.html#default_exercise_duration/0","title":"ExPomodoro.Pomodoro.default_exercise_duration/0","type":"function"},{"doc":"The default rounds number.","ref":"ExPomodoro.Pomodoro.html#default_rounds/0","title":"ExPomodoro.Pomodoro.default_rounds/0","type":"function"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct, returns a new struct with an increased round in an exercise activity.","ref":"ExPomodoro.Pomodoro.html#exercise/1","title":"ExPomodoro.Pomodoro.exercise/1","type":"function"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct, returns a new struct in an :idle activity.","ref":"ExPomodoro.Pomodoro.html#idle/1","title":"ExPomodoro.Pomodoro.idle/1","type":"function"},{"doc":"Given an id and a keyword of options, returns a new Elixir.ExPomodoro.Pomodoro struct. The options can redefine the following fields, otherwise the default values will be used: exercise_duration : the amount of time intended to spend on task completion, in milliseconds (default: 25 minutes). break_duration : the amount of time the break lasts, in milliseconds (default: 5 minutes). rounds : the number of rounds until the pomodoro finishes (default: 4 ).","ref":"ExPomodoro.Pomodoro.html#new/2","title":"ExPomodoro.Pomodoro.new/2","type":"function"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct, starts a new round by increasing the current round and assigning a new activity.","ref":"ExPomodoro.Pomodoro.html#start_round/1","title":"ExPomodoro.Pomodoro.start_round/1","type":"function"},{"doc":"Given a Elixir.ExPomodoro.Pomodoro struct and options, returns a new one with it's fields updated.","ref":"ExPomodoro.Pomodoro.html#update/2","title":"ExPomodoro.Pomodoro.update/2","type":"function"},{"doc":"","ref":"ExPomodoro.Pomodoro.html#t:activity/0","title":"ExPomodoro.Pomodoro.activity/0","type":"type"},{"doc":"","ref":"ExPomodoro.Pomodoro.html#t:id/0","title":"ExPomodoro.Pomodoro.id/0","type":"type"},{"doc":"","ref":"ExPomodoro.Pomodoro.html#t:opts/0","title":"ExPomodoro.Pomodoro.opts/0","type":"type"},{"doc":"","ref":"ExPomodoro.Pomodoro.html#t:t/0","title":"ExPomodoro.Pomodoro.t/0","type":"type"},{"doc":"The Pomodoro Server implementation","ref":"ExPomodoro.PomodoroServer.html","title":"ExPomodoro.PomodoroServer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"ExPomodoro.PomodoroServer.html#child_spec/1","title":"ExPomodoro.PomodoroServer.child_spec/1","type":"function"},{"doc":"Given a pid, returns the current state.","ref":"ExPomodoro.PomodoroServer.html#get_state/1","title":"ExPomodoro.PomodoroServer.get_state/1","type":"function"},{"doc":"Given a keyword of args returns a new map that represents the Elixir.ExPomodoro.PomodoroServer state.","ref":"ExPomodoro.PomodoroServer.html#initial_state/1","title":"ExPomodoro.PomodoroServer.initial_state/1","type":"function"},{"doc":"Given a pid, pauses a pomodoro and returns the current pomodoro state.","ref":"ExPomodoro.PomodoroServer.html#pause/1","title":"ExPomodoro.PomodoroServer.pause/1","type":"function"},{"doc":"Given a pid, resumes a pomodoro and returns the current pomodoro state.","ref":"ExPomodoro.PomodoroServer.html#resume/1","title":"ExPomodoro.PomodoroServer.resume/1","type":"function"},{"doc":"Given a keyword of arguments, starts a Elixir.GenServer process linked to the current process. Args: id : (required) unique string to identify a pomodoro struct. exercise : (optional) an integer that represents the duration of the time spent on exercise in milliseconds. break : (optional) an integer that represents the break duration in milliseconds. rounds : (optional) an integer that represents the amount of rounds until the pomodoro stops. timeout : (optional) milliseconds until the server is terminated by inactiviy.","ref":"ExPomodoro.PomodoroServer.html#start_link/1","title":"ExPomodoro.PomodoroServer.start_link/1","type":"function"},{"doc":"","ref":"ExPomodoro.PomodoroServer.html#t:init_args/0","title":"ExPomodoro.PomodoroServer.init_args/0","type":"type"},{"doc":"","ref":"ExPomodoro.PomodoroServer.html#t:state/0","title":"ExPomodoro.PomodoroServer.state/0","type":"type"},{"doc":"Specific implementation for the Pomodoro Supervisor","ref":"ExPomodoro.PomodoroSupervisor.html","title":"ExPomodoro.PomodoroSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"ExPomodoro.PomodoroSupervisor.html#child_spec/1","title":"ExPomodoro.PomodoroSupervisor.child_spec/1","type":"function"},{"doc":"Given a cart id, returns nil or a tuple where the first component is a Elixir.ExPomodoro.PomodoroServer pid and the second component the cart server state.","ref":"ExPomodoro.PomodoroSupervisor.html#get_child/1","title":"ExPomodoro.PomodoroSupervisor.get_child/1","type":"function"},{"doc":"Given a reference and some arguments starts a Elixir.ExPomodoro.PomodoroServer child and returns it's pid.","ref":"ExPomodoro.PomodoroSupervisor.html#start_child/2","title":"ExPomodoro.PomodoroSupervisor.start_child/2","type":"function"},{"doc":"Given a keyword of args, initialises the dynamic Pomodoro Supervisor.","ref":"ExPomodoro.PomodoroSupervisor.html#start_link/1","title":"ExPomodoro.PomodoroSupervisor.start_link/1","type":"function"},{"doc":"Given a reference and a child pid, terminates a Elixir.ExPomodoro.PomodoroServer process.","ref":"ExPomodoro.PomodoroSupervisor.html#terminate_child/2","title":"ExPomodoro.PomodoroSupervisor.terminate_child/2","type":"function"},{"doc":"Main Supervisor module for the ExPomodoro child_spec .","ref":"ExPomodoro.Supervisor.html","title":"ExPomodoro.Supervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"ExPomodoro.Supervisor.html#child_spec/1","title":"ExPomodoro.Supervisor.child_spec/1","type":"function"},{"doc":"Error message raised when the callback module is missing in the configuration.","ref":"ExPomodoro.Supervisor.html#missing_callback_module_error/0","title":"ExPomodoro.Supervisor.missing_callback_module_error/0","type":"function"},{"doc":"Starts a GenServer process linked to the current process.","ref":"ExPomodoro.Supervisor.html#start_link/1","title":"ExPomodoro.Supervisor.start_link/1","type":"function"},{"doc":"","ref":"ExPomodoro.Supervisor.html#t:config_error/0","title":"ExPomodoro.Supervisor.config_error/0","type":"type"},{"doc":"","ref":"ExPomodoro.Supervisor.html#t:init_arg/0","title":"ExPomodoro.Supervisor.init_arg/0","type":"type"},{"doc":"The ex_pomodoro program is a simple set of functions that let developers manage pomodoro sessions withing their Elixir applications. An Elixir Pomodoro 🍅","ref":"readme.html","title":"ExPomodoro","type":"extras"},{"doc":"About the Pomodoro technique ExPomodoro is an Elixir library that let developers easily manage pomodoro sessions by using a simple set of fuctions that can start a pomodoro session, pause a session, get the current session details. The motivation behind ExPomodoro development was initially driven by HTTP integrations in chat applications, such as Mattermost or Slack , where one could create slash commands that interact to an HTTP server or create bots that send and receive notifications. This library includes only the domain logic for managing pomodoro sessions.","ref":"readme.html#introduction","title":"ExPomodoro - Introduction","type":"extras"},{"doc":"If available in Hex , the package can be installed by adding ex_pomodoro to your list of dependencies in mix.exs : def deps do [ { :ex_pomodoro , &quot;~&gt; 1.0.1&quot; } ] end Otherwise it can be installed using the git remote url: def deps do [ { :ex_pomodoro , git : &quot;git@github.com:sgobotta/ex_pomodoro.git&quot; , tag : &quot;1.0.1&quot; } ] end","ref":"readme.html#installation","title":"ExPomodoro - Installation","type":"extras"},{"doc":"ExPomodoro uses a Supervisor and GenServer to perform runtime operations for pomodoros. Add the ExPomodoro child spec to your application tree. application.ex: @impl true def start ( _type , _args ) do children = [ ... ExPomodoro # &lt;- Add ExPomodoro to the children array ] opts = [ strategy : :one_for_one , name : MyApp.Supervisor ] Supervisor . start_link ( children , opts ) end Create a module that implements the following function. This is used to receive callbacks from the lib. your_callback_module.ex: defmodule MyApp.ExPomodoroClient do @moduledoc false require Logger @doc &quot;&quot;&quot; Helper function to test callbacks from the Pomodoro Server. &quot;&quot;&quot; @spec handle_activity_changed ( any ( ) ) :: :ok def handle_activity_changed ( payload ) do :ok = Logger . debug ( &quot; \#{ __MODULE__ } .handle_activity_changed payload= \#{ inspect ( payload , pretty : true ) } &quot; ) end end runtime.exs: config :ex_pomodoro , callback_module : MyApp.ExPomodoroClient","ref":"readme.html#setup","title":"ExPomodoro - Setup","type":"extras"},{"doc":"The ExPomodoro is the main module to interact with the APIs using a Pomodoro struct. There should be no need to use the rest of modules that handle runtime logic. A Pomodoro has four states: :idle , :exercise , :break , :finished Calling the APIs affect the state, and return an updated Pomodoro struct. All pomodoro functions are documented, check the ExPomodoro for more usage examples. Start a pomodoro session A %Pomodoro{} is created with an id that must be unique between sessions. Starting a pomodoro with a non-unique id will cause no effect. This command will create a pomodoro with default options. The work time is 25 minutes by default, the break time is 5 and the number of periods is 4 . iex&gt; ExPomodoro . start ( &quot;some id&quot; ) { :ok , % ExPomodoro.Pomodoro { id : &quot;some id&quot; , activity : :exercise , exercise_duration : 1_500_000 , break_duration : 300_000 , rounds : 4 } } Check the ExPomodoro module docs for examples with options. Pause a pomodoro session A %Pomodoro{} can be paused by passing the id . iex&gt; ExPomodoro . pause ( &quot;some id&quot; ) { :ok , % Pomodoro { id : &quot;some id&quot; , activity : :idle , current_duration : timeleft } } Get a pomodoro session A %Pomodoro{} can be obtained by passing the id . iex&gt; ExPomodoro . get ( &quot;some id&quot; ) { :ok , % ExPomodoro.Pomodoro { id : &quot;some id&quot; } } If the session does not exist, the function returns an error tuple. iex&gt; ExPomodoro . get ( &quot;some other id&quot; ) { :error , :not_found } A Pomodoro has a timeout of 90 minutes. if no interaction is made the Pomodoro will not be found and it's stats lost.","ref":"readme.html#usage","title":"ExPomodoro - Usage","type":"extras"},{"doc":"Requirements Elixir 1.11 or later. It should work on other versions but it isn't tested. If you use asdf just run asdf install in the root repository to install the required Elixir version. Installation and setup Install and compile dependencies and library. make setup Run format checks, credo, dialyzer and tests make check Run tests only make test Run test coverage make test.cover Run make to find a complete list of commands.","ref":"readme.html#development","title":"ExPomodoro - Development","type":"extras"},{"doc":"Allow callbacks on GenServer creation to support PubSub subscriptions, message passing, notifications and other real-time features. Allow description for pomodoro periods","ref":"readme.html#future-features","title":"ExPomodoro - Future features","type":"extras"},{"doc":"GNU General Public License version 3","ref":"readme.html#license","title":"ExPomodoro - License","type":"extras"}]